OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Käyttäjäistunto vanheni odottamatta",
    "Provided email-address is not valid" : "Annettu sähköpostiosoite ei ole kelvollinen",
    "%s has published the calendar »%s«" : "%s on julkaissut kalenterin  »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Odottamaton virhe sähköpostia lähettäessä. Ole yhteydessä ylläpitoon.",
    "Successfully sent email to " : "Sähköposti lähetettiin onnistuneesti",
    "Hello," : "Hei",
    "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin »%s«.",
    "Open »%s«" : "Avaa »%s«",
    "Cheers!" : "Kiitos!",
    "Calendar" : "Kalenteri",
    "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
    "Previous day" : "Edellinen päivä",
    "Previous week" : "Edellinen viikko",
    "Previous month" : "Edellinen kuukausi",
    "Next day" : "Seuraava päivä",
    "Next week" : "Seuraava viikko",
    "Next month" : "Seuraava kuukausi",
    "+ New event" : "+ Uusi tapahtuma",
    "Today" : "Tänään",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "Untitled calendar" : "Nimetön kalenteri",
    "Edit name" : "Muokkaa nimeä",
    "Saving name …" : "Tallennetaan nimi …",
    "Edit color" : "Muokkaa väriä",
    "Saving color …" : "Tallennetaan väri …",
    "Copy private link" : "Kopioi yksityinen linkki",
    "Download" : "Lataa",
    "Unshare from me" : "Lopeta jako minulle",
    "Delete" : "Poista",
    "An error occurred, unable to change visibility of the calendar." : "Tapahtui virhe. Kalenterin näkyvyyttä ei voitu muuttaa.",
    "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
    "An error occurred, unable to rename the calendar." : "Tapahtui virhe, kalenterin nimeäminen uudelleen ei onnistu.",
    "An error occurred, unable to change the calendar's color." : "Tapahtui virhe, kalenterin värin muuttaminen ei onnistu.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Poistetaan kalenterin jako {countdown} sekunnin kuluttua","Poistetaan kalenterin jako {countdown} sekunnin kuluttua"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnin kuluttua","Poistetaan kalenteri {countdown} sekunnin kuluttua"],
    "Share link" : "Jaa linkki",
    "Publish calendar" : "Julkaise kalenteri",
    "Publishing calendar" : "Julkaistaan kalenteri",
    "Copy public link" : "Kopioi julkinen linkki",
    "Send link to calendar via email" : "Lähetä kalenteriin johtava linkki sähköpostitse",
    "Enter one address" : "Kirjoita yksi osoite",
    "Sending email …" : "Lähetetään sähköpostia …",
    "Copy subscription link" : "Kopioi tilauslinkki",
    "Copying link …" : "Kopioidaan linkki …",
    "Copied link" : "Linkki kopioitu",
    "Could not copy link" : "Linkkiä ei voitu kopioida",
    "Copy embedding code" : "Kopioi upotuskoodi",
    "Copying code …" : "Kopioidaan koodi …",
    "Copied code" : "Koodi kopioitu",
    "Could not copy code" : "Koodia ei voitu kopioida",
    "Delete share link" : "Poista jakolinkki",
    "Deleting share link …" : "Poistetaan jakolinkki …",
    "An error occurred, unable to publish calendar." : "Tapahtui virhe, kalenterin julkaiseminen ei onnistu.",
    "An error occurred, unable to send email." : "Tapahtui virhe. Sähköpostia ei voitu lähettää.",
    "Embed code copied to clipboard." : "Upotuskoodi kopioitu leikepöydälle.",
    "Embed code could not be copied to clipboard." : "Upotuskoodia ei voitu kopioida leikepöydälle.",
    "Unpublishing calendar failed" : "Kalenterin julkaisun peruminen epäonnistui",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "can edit" : "voi muokata",
    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Tapahtui virhe, kalenterin poissa jakamista ei voi muokata.",
    "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
    "+ New calendar" : "+ Uusi kalenteri",
    "New calendar" : "Uusi kalenteri",
    "Creating calendar …" : "Luodaan kalenteri …",
    "New calendar with task list" : "Uusi kalenteri tehtävälistan kera",
    "New subscription from link (read-only)" : "Uusi tilaus linkistä (vain luku)",
    "Creating subscription …" : "Luodaan tilaus …",
    "An error occurred, unable to create the calendar." : "Tapahtui virhe, kalenteria ei voitu luoda.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Anna kelvollinen linkki (alkaen http://, https://, webcal:// tai webcals://)",
    "Import calendars" : "Tuo kalenterit",
    "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
    "Filename" : "Tiedostonimi",
    "Calendar to import into" : "Kalenteri johon tuodaan",
    "Cancel" : "Peruuta",
    "_Import calendar_::_Import calendars_" : ["Tuo kalenteri","Tuo kalenterit"],
    "{filename} is an unsupported file-type" : "{filename} ei ole tuettua tiedostotyyppiä",
    "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
    "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
    "Import partially failed. Imported {accepted} out of {total}." : "Tuonti epäonnistui osittain. Tuotiin {accepted}/{total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa."],
    "Automatic" : "Automaattinen",
    "Automatic ({detected})" : "Automaattinen ({detected})",
    "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
    "Shortcut overview" : "Pikakuvakenäkymä",
    "or" : "tai",
    "Navigation" : "Navigointi",
    "Views" : "Näyttökertaa",
    "Day view" : "Päivänäkymä",
    "Week view" : "Viikkonäkymä",
    "Month view" : "Kuukausinäkymä",
    "Actions" : "Toiminnot",
    "Create event" : "Luo tapahtuma",
    "Show shortcuts" : "Näytä pikakuvakkeet",
    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
    "Limit visible events per view" : "Rajoita näytettäviä tapahtumia näkymää kohden",
    "Show weekends" : "Näytä viikonloput",
    "Show week numbers" : "Näytä viikkonumerot",
    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
    "Settings & import" : "Asetukset ja tuonti",
    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
    "before at" : "ennen",
    "Notification" : "Ilmoitus",
    "Email" : "Sähköposti",
    "Audio notification" : "Ääni-ilmoitus",
    "Other notification" : "Muu ilmoitus",
    "Relative to event" : "Liittyy tapahtumaan",
    "On date" : "Päivänä",
    "Edit time" : "Muokkaa aikaa",
    "Save time" : "Tallenna aika",
    "Remove reminder" : "Poista muistutus",
    "+ Add reminder" : "+ Lisää muistutus",
    "_second_::_seconds_" : ["sekunti","sekuntia"],
    "_minute_::_minutes_" : ["minuutti","minuuttia"],
    "_hour_::_hours_" : ["tunti","tuntia"],
    "_day_::_days_" : ["päivä","päivää"],
    "_week_::_weeks_" : ["viikko","viikkoa"],
    "No reminders yet" : "Ei vielä muistutuksia",
    "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
    "Attendees, Resources and Rooms" : "Osallistujat, resurssit ja huoneet",
    "Busy (tentative)" : "Varattu (alustava)",
    "Busy" : "Varattu",
    "Out of office" : "Ulkona toimistolta",
    "Unknown" : "Tuntematon",
    "{name} accepted your invitation." : "{name} hyväksyi kutsusi.",
    "{name} accepted {organizerName}'s invitation." : "{name} hyväksyi järjestäjän {organizerName} kutsun.",
    "{name} declined your invitation." : "{name} kieltäytyi kutsustasi.",
    "{name} marked their participation as tentative." : "{name} merkitse osallistumisensa alustavaksi.",
    "{name} did not respond to your invitation yet." : "{name} ei ole vielä vastannut kutsuusi.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} ei ole vielä vastannut järjestäjän {organizerName} kutsuun.",
    "Create Talk room for this event" : "Luo Talk-huone tälle tapahtumalle",
    "Show busy times" : "Näytä varatut ajat",
    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
    "Send e-mail" : "Lähetä sähköpostia",
    "Chairperson" : "Puheenjohtaja",
    "Required participant" : "Vaadittu osallistuja",
    "Optional participant" : "Valinnainen osallistuja",
    "Non-participant" : "Osallistumaton",
    "Remove attendee" : "Poista osallistuja",
    "Search for e-mails, users, contacts, resources or rooms" : "Hae sähköpostiosoitteita, käyttäjiä, yhteystietoja, resursseja tai huoneita",
    "No match found" : "Ei tuloksia",
    "No attendees yet" : "Ei vielä osallistujia",
    "(organizer)" : "(järjestäjä)",
    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "Lähettääksesi kutsuja ja vastaanottaaksesi vastauksia,  [linkopen]lisää sähköpostiosoitteesi henkilökohtaisten asetusten kautta[linkclose].",
    "Remove color" : "Poista väri",
    "Event title" : "Tapahtuman otsikko",
    "All day" : "Koko päivä",
    "from {startDate}" : "alkaen {startDate}",
    "from {startDate} at {startTime}" : "alkaen {startDate} klo {startTime}",
    "to {endDate}" : "päättyen {endDate}",
    "to {endDate} at {endTime}" : "päättyen {endDate} klo {endTime}",
    "End repeat" : "Lopeta toisto",
    "Select to end repeat" : "Valitse lopettaaksesi toiston",
    "never" : "ei koskaan",
    "on date" : "päivänä",
    "after" : "jälkeen",
    "_time_::_times_" : ["kerran","kertaa"],
    "first" : "ensimmäinen",
    "third" : "kolmas",
    "fourth" : "neljäs",
    "fifth" : "viides",
    "second to last" : "toiseksi viimeinen",
    "last" : "viimeinen",
    "Repeat" : "Toista",
    "Repeat every" : "Toista joka",
    "By day of the month" : "Kuukauden päivän mukaan",
    "Monday" : "Maanantai",
    "weekday" : "viikonpäivä",
    "weekend day" : "viikonloppupäivä",
    "Summary" : "Yhteenveto",
    "More" : "Lisää",
    "Save" : "Tallenna",
    "Update" : "Päivitä",
    "Update this occurrence" : "Päivitä tämä esiintymä",
    "Update this and all future" : "Päivitä tämä ja kaikki tulevat",
    "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
    "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
    "Please select a timezone:" : "Valitse aikavyöhyke:",
    "Pick a time" : "Valitse aika",
    "Pick a date" : "Valitse päivä",
    "from {formattedDate}" : "alkaen {formattedDate}",
    "to {formattedDate}" : "päättyen {formattedDate}",
    "on {formattedDate}" : "päivänä {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "alkaen {formattedDate} klo {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "päättyen {formattedDate} klo {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "päivänä {formattedDate} klo {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} klo {formattedTime}",
    "Please enter a valid date" : "Kirjoita kelvollinen päivä",
    "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
    "Type to search timezone" : "Kirjoita etsiäksesi aikavyöhykettä",
    "Personal" : "Henkilökohtainen",
    "Delete this occurrence" : "Poista tämä esiintymä",
    "Delete this and all future" : "Poista tämä ja kaikki tulevat",
    "Details" : "Tiedot",
    "Attendees" : "Osallistujat",
    "Reminders" : "Muistutukset",
    "Activity" : "Tapahtumat",
    "Projects" : "Projektit",
    "Show more details" : "Näytä lisää tietoja",
    "Close" : "Sulje",
    "Subscribe to {name}" : "Tilaa {name}",
    "Download {name}" : "Lataa {name}",
    "Anniversary" : "Vuosipäivä",
    "Appointment" : "Tapaaminen",
    "Business" : "Business",
    "Education" : "Koulutus",
    "Holiday" : "Loma",
    "Meeting" : "Tapaaminen",
    "Miscellaneous" : "Sekalaiset",
    "Non-working hours" : "Ei-työnalaiset tunnit",
    "Not in office" : "Pois työpaikalta",
    "Phone call" : "Puhelinkeskustelu",
    "Sick day" : "Sairauspäivä",
    "Special occasion" : "Erikoistilaisuus",
    "Travel" : "Matka",
    "Vacation" : "Loma",
    "Midnight on the day the event starts" : "Keskiyöllä tapahtumapäivänä",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n päivä ennen tapahtumaa klo {formattedHourMinute}","%n  päivää ennen tapahtumaa klo {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n viikko ennen tapahtumaa klo {formattedHourMinute}","%n viikkoa ennen tapahtumaa klo {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "tapahtumapäivänä klo {formattedHourMinute}",
    "at the event's start" : "tapahtuman alkaessa",
    "at the event's end" : "tapahtuman päättyessä",
    "{time} before the event starts" : "{time} ennen tapahtuman alkua",
    "{time} before the event ends" : "{time} ennen tapahtuman päättymistä",
    "{time} after the event starts" : "{time} tapahtuman alkamisen jälkeen",
    "{time} after the event ends" : "{time} tapahtuman päättymisen jälkeen",
    "on {time}" : "klo {time}",
    "on {time} ({timezoneId})" : "klo {time} ({timezoneId})",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Does not repeat" : "Ei toistu",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Monthly" : "Kuukausittain",
    "Yearly" : "Vuosittain",
    "in {monthNames}" : "kuukausina {monthNames}",
    "_%n time_::_%n times_" : ["%n kerran","%n kertaa"],
    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
    "Untitled event" : "Nimetön tapahtuma",
    "Untitled task" : "Nimetön tehtävä",
    "When shared show" : "Jaettaessa näytä",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
    "Location" : "Sijainti",
    "Add a location" : "Lisää sijainti",
    "Description" : "Kuvaus",
    "Add a description" : "Lisää kuvaus",
    "Status" : "Tila",
    "Confirmed" : "Vahvistettu",
    "Tentative" : "Alustava",
    "Cancelled" : "Peruttu",
    "Show as" : "Näytä muodossa",
    "Take this event into account when calculating free-busy information." : "Huomioi tämä tapahtuma laskettaessa vapaita ja varattuja ajankohtia.",
    "Free" : "Vapaa",
    "Categories" : "Luokat",
    "Categories help you to structure and organize your events." : "Luokat auttavat sinua asettamaan tapahtumia rakenteellisiksi ja hallitsemaan niitä.",
    "Search or add categories" : "Etsi tai lisää luokkia",
    "Add this as a new category" : "Lisää tämä uutena luokkana",
    "Custom color" : "Mukautettu väri",
    "Special color of this event. Overrides the calendar-color." : "Tämän tapahtuman erikoisväri. Ylittää kalenterin väriarvon.",
    "Chat room for event" : "Tapahtuman keskusteluhuone",
    "Imported {filename}" : "Tuotiin {filename}",
    "Meditation" : "Meditaatio",
    "Relaxing" : "Rentoutumista",
    "Relax" : "Rentoutumista",
    "Presentation" : "Esitys",
    "Present" : "Lahja",
    "Camping" : "Telttailua",
    "Camp" : "Leiri",
    "Movie" : "Elokuva",
    "Cinema" : "Elokuvateatteri",
    "Graduation" : "Valmistujaiset",
    "Brainstorm" : "Brainstorm",
    "Baseball" : "Pesäpallo",
    "Meet" : "Liity",
    "Planning" : "Suunnittelua",
    "Pointing" : "Osoittaa",
    "Retrospective" : "Retrospektiivinen",
    "Review" : "Esikatsele",
    "Office" : "Toimisto",
    "Party" : "Juhlat",
    "Celebration" : "Juhlintaa",
    "Mail" : "Sähköposti",
    "Soccer" : "Jalkapallo",
    "Football" : "Jalkapallo",
    "Gaming" : "Pelailua",
    "Play" : "Esitys",
    "Game" : "Peli",
    "Drive" : "Ajo",
    "Bicycle" : "Polkupyöräily",
    "Cycle" : "Polkupyöräily",
    "Biking" : "Polkupyöräily",
    "Podcast" : "Podcast",
    "Basketball" : "Koripallo",
    "Fishing" : "Kalastus",
    "Hiking" : "Retkeily",
    "Hike" : "Vaellus",
    "Art" : "Taide",
    "Exhibition" : "Näyttely",
    "Museum" : "Museo",
    "Pilates" : "Pilates",
    "Park" : "Puisto",
    "Studying" : "Opiskelua",
    "Doctor" : "Lääkäri",
    "Health" : "Terveys",
    "Dentist" : "Hammaslääkäri",
    "Interview" : "Haastattelu",
    "Training" : "Treenit",
    "Practice" : "Harjoittele",
    "Sports" : "Liikuntaa",
    "Exercise" : "Harjoitukset",
    "Work out" : "Bodausta",
    "Working out" : "Kuntosali",
    "Gym" : "Sali",
    "Barber" : "Parturi",
    "Haircut" : "Kampaamo",
    "Exam" : "Koe",
    "Working" : "Töitä",
    "New Years Eve" : "Uudenvuodenaatto",
    "NYE" : "NYE",
    "Fireworks" : "Ilotulitus",
    "Running" : "Juoksua",
    "Go for a run" : "Mene lenkille",
    "Marathon" : "Maraton",
    "Video-conference" : "Videokonfrenssi",
    "Video-call" : "Videopuhelu",
    "Video-chat" : "Videokeskustelu",
    "Video-meeting" : "Videotapaaminen",
    "Call" : "Puhelu",
    "Calling" : "Puhelu",
    "Christmas" : "Joulu",
    "Conference" : "Konfrenssi",
    "Pizza" : "Pizza",
    "Travelling" : "Reissaamista",
    "Journey" : "Matka",
    "Collaborate" : "Yhteistyötä",
    "Pair" : "Yhdistä",
    "Lecture" : "Luento",
    "Seminar" : "Seminaari",
    "Photograph" : "Valokuvaus",
    "Celebrate" : "Juhli",
    "Shopping" : "Ostokset",
    "Skate" : "Skeittausta",
    "Skateboard" : "Skeittaus",
    "Wine tasting" : "Viininmaistelu",
    "Golf" : "Golf",
    "Lunch" : "Lounas",
    "Global" : "Julkinen"
},
"nplurals=2; plural=(n != 1);");
